@@ -581,7 +581,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     var that = this;
                     serverCall.callAsyncSmart(function (cookie) {
                         form.append('xsc', cookie);
-                        that._uploadForm(form);
+                        that._uploadForm(form,btCfg.busyMessage);
                     }, 'getSessionCookie');
                 } else {
                     callbackery.ui.MsgBox.getInstance().error(
@@ -594,11 +594,13 @@ qx.Class.define("callbackery.ui.plugin.Action", {
             return button;
         },
 
-        _uploadForm(form) {
+        _uploadForm(form,busyMessage) {
             var req = new qx.io.request.Xhr("upload", 'POST').set({
                 requestData: form
             });
+            let busy = callbackery.ui.Busy.getInstance();
             req.addListener('success', function (e) {
+                busy.vanish();                
                 var response = req.getResponse();
                 if (response.exception) {
                     callbackery.ui.MsgBox.getInstance().error(
@@ -613,6 +615,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
             }, this);
             req.addListener('fail', function (e) {
                 var response = {};
+                busy.vanish();
                 try {
                     response = req.getResponse();
                 }
@@ -631,6 +634,11 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                 );
                 req.dispose();
             });
+            if (busyMessage) {
+                busy.manifest(this.xtr(busyMessage));
+            } else {
+                busy.manifest(this.tr('Uploading File, please wait ...'));
+            }
             req.send();
         },
 
